==> ejc-proother-impl-3.0.0-20220329.124042-20-sources.jar: com/ejianc/business/settle/bean/SettleOtherEntity.java <==
package com.ejianc.business.settle.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算 其他费用
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proother_settle_other")
public class SettleOtherEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="settle_id")
    private Long settleId; // 结算id
    @TableField(value="source_type")
    private String sourceType; // 来源:合同内，合同外
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="project_id")
    private Long projectId; // 项目Id
    @TableField(value="source_id")
    private Long sourceId; // 其他费用id
    @TableField(value="cost_name")
    private String costName; // 费用项
    @TableField(value="cost_tax_rate")
    private BigDecimal costTaxRate; // 税率
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 本期结算金额，本期结算金额=本期结算量*单价
    @TableField(value="mny")
    private BigDecimal mny; // 本期结算金额(无税)
    @TableField(value="tax")
    private BigDecimal tax; // 本期结算税额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="settle_type")
    private Integer settleType; // 结算类型：0-过程，1-完工
    @TableField(value = "use_flag")
    private Integer useFlag; // 是否引用过,否-0，是-1

    public Integer getSettleType() {
        return settleType;
    }

    public Integer getUseFlag() {
        return useFlag;
    }

    public void setUseFlag(Integer useFlag) {
        this.useFlag = useFlag;
    }

    public void setSettleType(Integer settleType) {
        this.settleType = settleType;
    }

    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public BigDecimal getCostTaxRate() {
        return costTaxRate;
    }

    public void setCostTaxRate(BigDecimal costTaxRate) {
        this.costTaxRate = costTaxRate;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-proother-impl-3.0.0-20220520.083633-73-sources.jar: com/ejianc/business/settle/bean/SettleOtherEntity.java <==
package com.ejianc.business.settle.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算 其他费用
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proother_settle_other")
public class SettleOtherEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="settle_id")
    private Long settleId; // 结算id
    @TableField(value="source_type")
    private String sourceType; // 来源:合同内，合同外
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="project_id")
    private Long projectId; // 项目Id
    @TableField(value="source_id")
    private Long sourceId; // 其他费用id
    @TableField(value="cost_name")
    private String costName; // 费用项
    @TableField(value="cost_tax_rate")
    private BigDecimal costTaxRate; // 税率
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 本期结算金额，本期结算金额=本期结算量*单价
    @TableField(value="mny")
    private BigDecimal mny; // 本期结算金额(无税)
    @TableField(value="tax")
    private BigDecimal tax; // 本期结算税额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="settle_type")
    private Integer settleType; // 结算类型：0-过程，1-完工
    @TableField(value = "use_flag")
    private Integer useFlag; // 是否引用过,否-0，是-1
    @TableField(value = "other_wbs_id")
    private Long otherWbsId; // 核算对象主键
    @TableField(value = "other_wbs_name")
    private String otherWbsName; // 核算对象名称
    @TableField(value = "other_wbs_code")
    private String otherWbsCode; // 核算对象编码
    @TableField(value = "other_subject_id")
    private Long otherSubjectId; // 成本科目主键
    @TableField(value = "other_subject_name")
    private String otherSubjectName; // 成本科目名称
    @TableField(value = "other_subject_code")
    private String otherSubjectCode; // 成本科目编码

    public Long getOtherWbsId() {
        return otherWbsId;
    }

    public void setOtherWbsId(Long otherWbsId) {
        this.otherWbsId = otherWbsId;
    }

    public String getOtherWbsName() {
        return otherWbsName;
    }

    public void setOtherWbsName(String otherWbsName) {
        this.otherWbsName = otherWbsName;
    }

    public String getOtherWbsCode() {
        return otherWbsCode;
    }

    public void setOtherWbsCode(String otherWbsCode) {
        this.otherWbsCode = otherWbsCode;
    }

    public Long getOtherSubjectId() {
        return otherSubjectId;
    }

    public void setOtherSubjectId(Long otherSubjectId) {
        this.otherSubjectId = otherSubjectId;
    }

    public String getOtherSubjectName() {
        return otherSubjectName;
    }

    public void setOtherSubjectName(String otherSubjectName) {
        this.otherSubjectName = otherSubjectName;
    }

    public String getOtherSubjectCode() {
        return otherSubjectCode;
    }

    public void setOtherSubjectCode(String otherSubjectCode) {
        this.otherSubjectCode = otherSubjectCode;
    }

    public Integer getSettleType() {
        return settleType;
    }

    public Integer getUseFlag() {
        return useFlag;
    }

    public void setUseFlag(Integer useFlag) {
        this.useFlag = useFlag;
    }

    public void setSettleType(Integer settleType) {
        this.settleType = settleType;
    }

    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public BigDecimal getCostTaxRate() {
        return costTaxRate;
    }

    public void setCostTaxRate(BigDecimal costTaxRate) {
        this.costTaxRate = costTaxRate;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
